@@ -1,21 +1,23 @@
 /*
 *  Name:
-*     grf_2.0.c
+*     grf_5.6.c
 
 *  Purpose:
-*     Implement the grf module required by AST V2.0 if no graphics system
+*     Implement the grf module required by AST V5.6 if no graphics system
 *     is available.
 
 *  Description:
 *     This file implements the low level graphics functions required
-*     by the rest of AST V2.0, by reporting errors when called.
+*     by the rest of AST V5.6, except for those already defined in
+*     earlier grf_xxx.c files (i.e. those needed by ealier versions
+*     of AST). These implementations simply report an error when called.
 
 *  Inheritance:
 *     This module is not a class and does not inherit.
 
 *  Copyright:
-*     Copyright (C) 1997-2006 Council for the Central Laboratory of the
-*     Research Councils
+*     Copyright (C) 2011 Science & Technology Facilities Council.
+*     All Rights Reserved.
 
 *  Licence:
 *     This program is free software; you can redistribute it and/or
@@ -37,12 +39,8 @@
 *     DSB: David S. Berry (Starlink)
 
 *  History:
-*     23-OCT-1996 (DSB):
+*     4-MAR-2011 (DSB):
 *        Original version.
-*     13-NOV-1996 (DSB):
-*        Modified to issue error messages using astError instead of printf.
-*     23-NOV-2004 (DSB):
-*        Renamed from grf_null.c
 */
 
 /* Header files */
@@ -57,45 +55,23 @@ static void Report( const char * );
 
 /* Function definitions */
 /* ==================== */
-int astGFlush( void ){
-   Report( "astGFlush");
+int astGBBuf( void ){
+   Report( "astGBBuf" );
    return 0;
 }
 
-int astGLine( int n, const float *x, const float *y ){
-   Report( "astGLine" );
-   return 0;
-}
-
-int astGQch( float *chv, float *chh ){
-   Report( "astGQch" );
-   return 0;
-}
-
-int astGMark( int n, const float *x, const float *y, int type ){
-   Report( "astGMark" );
-   return 0;
-}
-
-int astGText( const char *text, float x, float y, const char *just,
-              float upx, float upy ){
-   Report( "astGText" );
-   return 0;
-}
-
-int astGTxExt( const char *text, float x, float y, const char *just,
-               float upx, float upy, float *xb, float *yb ){
-   Report( "astGTxExt" );
-   return 0;
-}
-
-int astGAttr( int attr, double value, double *old_value, int prim ){
-   Report( "astGAttr" );
+int astGEBuf( void ){
+   Report( "astGEBuf" );
    return 0;
 }
 
 static void Report( const char *name ){
-   astError( AST__GRFER, "%s: No graphics facilities are available.", name );
-   astError( AST__GRFER, "Re-link using an option such as '-pgplot' with "
-             "the ast_link script." );
+   astError( AST__GRFER, "%s: The graphics facilities implement by %s "
+             "(introduced at AST V5.6) are needed but are unavailable.",
+             name, name );
+   astError( AST__GRFER, "Re-link using a suitable option such as '-pgplot' "
+             "with the ast_link script, or add an implementation of this "
+             "function to your 'grf' module." );
 }
+
+
