@@ -111,9 +111,10 @@ typedef struct AstMapEntry {
    int nel;                  /* 0 => scalar, >0 => array with "nel" elements */
    const char *comment;      /* Pointer to a comment for the entry */
    int defined;              /* Non-zero if the entry value is defined */
-   struct AstMapEntry *snext; /* Pointer to next structure in sorted list. */
-   struct AstMapEntry *sprev; /* Pointer to previous structure in sorted list. */
-   int member;               /* No. of entries added to KeyMap prior to this one  */
+   struct AstMapEntry *snext;/* Pointer to next structure in sorted list. */
+   struct AstMapEntry *sprev;/* Pointer to previous structure in sorted list. */
+   int member;               /* No. of values added to KeyMap prior to this one  */
+   int keymember;            /* No. of keys added to KeyMap prior to this one  */
    int sortby;               /* Used for comunnication with qsort function */
 } AstMapEntry;
 
@@ -138,7 +139,7 @@ typedef struct AstKeyMap {
    int sortby;                     /* How the keys should be sorted */
    AstMapEntry *first;             /* Pointer to first structure in sorted list. */
    int nsorted;                    /* Length of sorted list */
-   int member_count;               /* Total no. of entries ever added to keyMap */
+   int member_count;               /* Total no. of values ever added to keyMap */
    AstMapEntry *firstA;            /* Pointer to first "AST object"-type entry */
    int iter_itab;                  /* Next hash table entry to return */
    AstMapEntry *iter_entry;        /* Next entry to return */
